public class Card {
    private final int rank;
    private final int suit;

    // Kinds of suits
    public final static int DIAMONDS = 1;
    public final static int CLUBS    = 2;
    public final static int HEARTS   = 3;
    public final static int SPADES   = 4;

    // Kinds of ranks
    public final static int ACE   = 1;
    public final static int DEUCE = 2;
    public final static int THREE = 3;
    public final static int FOUR  = 4;
    public final static int FIVE  = 5;
    public final static int SIX   = 6;
    public final static int SEVEN = 7;
    public final static int EIGHT = 8;
    public final static int NINE  = 9;
    public final static int TEN   = 10;
    public final static int JACK  = 11;
    public final static int QUEEN = 12;
    public final static int KING  = 13;

    public Card(int rank, int suit) {
        assert isValidRank(rank);
        assert isValidSuit(suit);
        this.rank = rank;
        this.suit = suit;
    }

    public int getSuit() {
        return suit;
    }

    public int getRank() {
        return rank;
    }

    public static boolean isValidRank(int rank) {
        return ACE <= rank && rank <= KING;
    }

    public static boolean isValidSuit(int suit) {
        return DIAMONDS <= suit && suit <= SPADES;
    }

    public static String rankToString(int rank) {
        switch (rank) {
        case ACE:
            return "Ace";
        case DEUCE:
            return "Deuce";
        case THREE:
            return "Three";
        case FOUR:
            return "Four";
        case FIVE:
            return "Five";
        case SIX:
            return "Six";
        case SEVEN:
            return "Seven";
        case EIGHT:
            return "Eight";
        case NINE:
            return "Nine";
        case TEN:
            return "Ten";
        case JACK:
            return "Jack";
        case QUEEN:
            return "Queen";
        case KING:
            return "King";
        default:
            //Handle an illegal argument.  There are generally two
            //ways to handle invalid arguments, throwing an exception
            //(see the section on Handling Exceptions):
            throw new IllegalArgumentException("Invalid rank " + rank);
            //or
            //return null;
        }
    }

    public static String suitToString(int suit) {
        switch (suit) {
        case DIAMONDS:
            return "Diamonds";
        case CLUBS:
            return "Clubs";
        case HEARTS:
            return "Hearts";
        case SPADES:
            return "Spades";
        default:
            throw new IllegalArgumentException("Invalid suit " + suit);
        }
    }

    public static void main(String... args) {
        assert rankToString(ACE).equals("Ace");
        assert rankToString(DEUCE).equals("Deuce");
        assert rankToString(THREE).equals("Three");
        assert rankToString(FOUR).equals("Four");
        assert rankToString(FIVE).equals("Five");
        assert rankToString(SIX).equals("Six");
        assert rankToString(SEVEN).equals("Seven");
        assert rankToString(EIGHT).equals("Eight");
        assert rankToString(NINE).equals("Nine");
        assert rankToString(TEN).equals("Ten");
        assert rankToString(JACK).equals("Jack");
        assert rankToString(QUEEN).equals("Queen");
        assert rankToString(KING).equals("King");

        assert suitToString(DIAMONDS).equals("Diamonds");
        assert suitToString(CLUBS).equals("Clubs");
        assert suitToString(HEARTS).equals("Hearts");
        assert suitToString(SPADES).equals("Spades");

        new Card(ACE, DIAMONDS);
        new Card(KING, SPADES);

        boolean failed = false;
        try {
            new Card(ACE - 1, DIAMONDS - 1);
        } catch (AssertionError ex) {
            failed = true;
        }
        assert failed;

        failed = false;
        try {
            new Card(KING + 1, SPADES + 1);
        } catch (AssertionError ex) {
            failed = true;
        }
        assert failed;
    }
}
